History
-------

0.1.0 (2017-09-25)
++++++++++++++++++

* Initial release

0.1.2 (2017-09-26)
++++++++++++++++++

* Merge Quickstart section into README

0.1.3 (2017-09-26)
++++++++++++++++++

* Add missing HISTORY.rst to manifst

0.1.4 (2017-09-26)
++++++++++++++++++

* Support for ``order_field`` attribute for ``list_display`` method fields.
  This works similar to ``ModelAdmin`` method fields' ``admin_order_field``
  property.

0.1.5 (2017-09-26)
++++++++++++++++++

* Better unicode support

0.1.6 (2017-09-27)
++++++++++++++++++

* Better access control support through 'login_url' & 'raise_exception'
  PopupCrudViewSet properties
